@@ -4,24 +4,13 @@ set -e
 
 BUILDDEPENDS="curl jq coreutils gcc gettext musl-dev"
 RUNDEPENDS="git git-daemon unzip openssh gnupg"
-
-if echo "$PYTHON" | grep -q ^2
-then
-    PIPDEPENDS="$PIPDEPENDS dulwich~=0.19.0"
-else
-    PIPDEPENDS="$PIPDEPENDS dulwich pyflakes"
-fi
-
-if test "$PYTHON" -gt 3.5
-then
-    PIPDEPENDS="$PIPDEPENDS black==20.8b1"
-fi
+PIPDEPENDS="black==22.3 coverage dulwich pyflakes pygments pylint"
 
 set -xe
 
 apk add --no-cache $BUILDDEPENDS $RUNDEPENDS
 
-python -m pip --no-cache-dir install $PIPDEPENDS
+python -m pip --no-cache-dir install --pre $PIPDEPENDS
 
 # handle pre-release versions
 get_version() {
